@@ -5,24 +5,14 @@
 class Error(Exception):
     """Base error class."""
 
-    def __init__(self, message=None):
-        """Initialize."""
-        super(Error, self).__init__(message)
-
 
 class NotFound(Error):
     """Not Found."""
 
-    pass
-
 
 class Conflict(Error):
     """Confilict."""
 
-    pass
-
 
 class BackendFailure(Error):
     """PyPI service down."""
-
-    pass
